from setuptools import setup

setup(name='socialblade',
      version='1.0.5',
      description='Object oriented SocialBlade API wrapper',
      author='sl4v',
      author_email='iamsl4v@gmail.com',
      url='https://github.com/sl4vkek/python-socialblade',
      packages=['socialblade'],
      install_requires=['cloudscraper', 'dateparser'],
      license="UNLICENSE"
     )
